Index: /trunk/ippToPsps/config/settings.xml
===================================================================
--- /trunk/ippToPsps/config/settings.xml	(revision 38963)
+++ /trunk/ippToPsps/config/settings.xml	(revision 38964)
@@ -12,6 +12,6 @@
       <name>ipptopsps2_scratch</name>
       <host>ipp006</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>16</memory>
     </loader>
@@ -19,6 +19,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stare00</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>64</memory>
     </loader>
@@ -26,6 +26,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stare01</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>64</memory>
     </loader>
@@ -33,6 +33,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stare02</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>64</memory>
     </loader>
@@ -40,6 +40,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stare03</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>64</memory>
     </loader>
@@ -47,6 +47,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stare04</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>64</memory>
     </loader>
@@ -54,6 +54,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci00</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -61,6 +61,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci01</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -68,6 +68,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci02</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -75,6 +75,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci03</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -82,6 +82,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci04</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -89,6 +89,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci05</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -96,6 +96,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci06</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -103,6 +103,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci07</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -110,6 +110,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci08</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -117,6 +117,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci09</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -124,6 +124,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci10</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -131,6 +131,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci11</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -138,6 +138,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci12</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -145,6 +145,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci13</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -152,6 +152,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci14</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -159,6 +159,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci15</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -166,6 +166,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci16</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -173,6 +173,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci17</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -180,6 +180,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci18</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -187,6 +187,6 @@
       <name>ipptopsps2_scratch</name>
       <host>stsci19</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -198,6 +198,6 @@
       <name>ipptopsps_scratch</name>
       <host>localhost</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>16</memory>
     </loader>
@@ -210,6 +210,6 @@
     <name>gpc1</name>
     <host>ippdb05</host>
-    <user>ippuser</user>
-    <password>ippuser</password>
+    <user>ipp</user>
+    <password>ipp</password>
   </gpc1database>
 
@@ -218,6 +218,6 @@
     <name>ipptopsps2</name>
     <host>ipp006</host>
-    <user>czw</user>
-    <password>czw</password>
+    <user>dvo</user>
+    <password>dvo</password>
   </ipptopspsdatabase>
 
@@ -227,6 +227,6 @@
       <name>ipptopsps_test_scratch</name>
       <host>ipp006</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>16</memory>
     </loader>
@@ -234,6 +234,6 @@
       <name>ipptopsps_test_scratch</name>
       <host>ipp064</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>32</memory>
     </loader>
@@ -241,6 +241,6 @@
       <name>ipptopsps_test_scratch</name>
       <host>pikake</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>2</memory>
     </loader>
@@ -248,6 +248,6 @@
       <name>ipptopsps_test_scratch</name>
       <host>localhost</host>
-      <user>czw</user>
-      <password>czw</password>
+      <user>dvo</user>
+      <password>dvo</password>
       <memory>2</memory>
     </loader>
@@ -260,6 +260,6 @@
     <name>gpc1test</name>
     <host>localhost</host>
-    <user>czw</user>
-    <password>czw</password>
+    <user>dvo</user>
+    <password>dvo</password>
   </gpc1database_test>
 
@@ -268,6 +268,6 @@
     <name>ipptopsps_test</name>
     <host>localhost</host>
-    <user>czw</user>
-    <password>czw</password>
+    <user>dvo</user>
+    <password>dvo</password>
   </ipptopspsdatabase_test>
 
@@ -276,6 +276,6 @@
     <name>czardb</name>
     <host>ippdb05</host>
-    <user>ippuser</user>
-    <password>ippuser</password>
+    <user>ipp</user>
+    <password>ipp</password>
   </czardatabase>
 
Index: /trunk/ippToPsps/config/tables.FG.vot
===================================================================
--- /trunk/ippToPsps/config/tables.FG.vot	(revision 38963)
+++ /trunk/ippToPsps/config/tables.FG.vot	(revision 38964)
@@ -74,4 +74,16 @@
         <DESCRIPTION>Error in galaxy fit magnitude for g filter measurement.</DESCRIPTION>
       </FIELD>
+      <FIELD name="gGalRa" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Right ascension offset of Sersic (1963) fit from PSF right ascension for g filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="gGalDec" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Declination offset of Sersic (1963) fit from PSF declination for g filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="gGalRaErr" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Error in right ascension offset of Sersic (1963) fit from PSF right ascension for g filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="gGalDecErr" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Error in declination offset of Sersic (1963) fit from PSF declination for g filter measurement.</DESCRIPTION>
+      </FIELD>
       <FIELD name="gGalChisq" arraysize="1" datatype="float" unit="dimensionless" default="-999">
         <DESCRIPTION>Reduced chi squared value for g filter measurement.</DESCRIPTION>
@@ -102,4 +114,16 @@
         <DESCRIPTION>Error in galaxy fit magnitude for r filter measurement.</DESCRIPTION>
       </FIELD>
+      <FIELD name="rGalRa" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Right ascension offset of Sersic (1963) fit from PSF right ascension for r filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="rGalDec" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Declination offset of Sersic (1963) fit from PSF declination for r filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="rGalRaErr" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Error in right ascension offset of Sersic (1963) fit from PSF right ascension for r filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="rGalDecErr" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Error in declination offset of Sersic (1963) fit from PSF declination for r filter measurement.</DESCRIPTION>
+      </FIELD>
       <FIELD name="rGalChisq" arraysize="1" datatype="float" unit="dimensionless" default="-999">
         <DESCRIPTION>Reduced chi squared value for r filter measurement.</DESCRIPTION>
@@ -130,4 +154,16 @@
         <DESCRIPTION>Error in galaxy fit magnitude for i filter measurement.</DESCRIPTION>
       </FIELD>
+      <FIELD name="iGalRa" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Right ascension offset of Sersic (1963) fit from PSF right ascension for i filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="iGalDec" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Declination offset of Sersic (1963) fit from PSF declination for i filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="iGalRaErr" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Error in right ascension offset of Sersic (1963) fit from PSF right ascension for i filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="iGalDecErr" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Error in declination offset of Sersic (1963) fit from PSF declination for i filter measurement.</DESCRIPTION>
+      </FIELD>
       <FIELD name="iGalChisq" arraysize="1" datatype="float" unit="dimensionless" default="-999">
         <DESCRIPTION>Reduced chi squared value for i filter measurement.</DESCRIPTION>
@@ -158,4 +194,16 @@
         <DESCRIPTION>Error in galaxy fit magnitude for z filter measurement.</DESCRIPTION>
       </FIELD>
+      <FIELD name="zGalRa" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Right ascension offset of Sersic (1963) fit from PSF right ascension for z filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="zGalDec" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Declination offset of Sersic (1963) fit from PSF declination for z filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="zGalRaErr" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Error in right ascension offset of Sersic (1963) fit from PSF right ascension for z filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="zGalDecErr" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Error in declination offset of Sersic (1963) fit from PSF declination for z filter measurement.</DESCRIPTION>
+      </FIELD>
       <FIELD name="zGalChisq" arraysize="1" datatype="float" unit="dimensionless" default="-999">
         <DESCRIPTION>Reduced chi squared value for z filter measurement.</DESCRIPTION>
@@ -185,4 +233,16 @@
       <FIELD name="yGalMagErr" arraysize="1" datatype="float" unit="AB magnitudes" default="-999">
         <DESCRIPTION>Error in galaxy fit magnitude for y filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="yGalRa" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Right ascension offset of Sersic (1963) fit from PSF right ascension for y filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="yGalDec" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Declination offset of Sersic (1963) fit from PSF declination for y filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="yGalRaErr" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Error in right ascension offset of Sersic (1963) fit from PSF right ascension for y filter measurement.</DESCRIPTION>
+      </FIELD>
+      <FIELD name="yGalDecErr" arraysize="1" datatype="float" unit="arcsec" default="-999">
+        <DESCRIPTION>Error in declination offset of Sersic (1963) fit from PSF declination for y filter measurement.</DESCRIPTION>
       </FIELD>
       <FIELD name="yGalChisq" arraysize="1" datatype="float" unit="dimensionless" default="-999">
Index: /trunk/ippToPsps/jython/forcedgalaxybatch.py
===================================================================
--- /trunk/ippToPsps/jython/forcedgalaxybatch.py	(revision 38963)
+++ /trunk/ippToPsps/jython/forcedgalaxybatch.py	(revision 38964)
@@ -142,5 +142,5 @@
         for filter in filters:
             filterID = self.scratchDb.getFilterId(filter[1])
-            photcode = self.scratchDb.getPhotoCalID("GPC1." + filter[1] + ".ForcedWarp")
+
 
             # This is going to need to join elsewhere to get all the fields?
@@ -148,43 +148,22 @@
             # Ra, Dec, RaErr, DecErr
             
-            # This won't work, as we need to join on modeltype/obj_id/filter
-#                + cpqTable + " AS cpq ON (cpq.row = (ForcedGalaxyShape.row* " + str(filterCount) + ")-(" + str(filterCount) + " - " + str(filter[0]) + ")) " \ 
-#                + " ForcedGalaxyShape." + filter[1] + "GalModelType               = MODEL_TYPE," \
-
-            # Should GalChiSq fold in Npix somehow? 
-#             sql = "UPDATE ForcedGalaxyShape JOIN " \
-#                + cpqTable + " AS cpq ON (cpq.row = (ForcedGalaxyShape.row* " + str(filterCount) + ")-(" + str(filterCount) + " - " + str(filter[0]) + ")) " \ 
-#                 + " SET " + \
-#                 + " ForcedGalaxyShape." + filter[1] + "ippDetectID                = DET_ID," \
-#                 + " ForcedGalaxyShape." + filter[1] + "forcedSummaryID            = IMAGE_ID," \
-#                 + " ForcedGalaxyShape." + filter[1] + "GalMajor                   = MAJOR_AXIS," \
-#                 + " ForcedGalaxyShape." + filter[1] + "GalMajorErr                = MAJOR_AXIS_ERR," \
-#                 + " ForcedGalaxyShape." + filter[1] + "GalMinor                   = MINOR_AXIS," \
-#                 + " ForcedGalaxyShape." + filter[1] + "GalMinorErr                = MINOR_AXIS_ERR," \
-#                 + " ForcedGalaxyShape." + filter[1] + "GalMag                     = MAG," \
-#                 + " ForcedGalaxyShape." + filter[1] + "GalMagErr                  = MAG_ERR," \
-#                 + " ForcedGalaxyShape." + filter[1] + "GalRa                      = RA," \
-#                 + " ForcedGalaxyShape." + filter[1] + "GalDec                     = DEC," \
-#                 + " ForcedGalaxyShape." + filter[1] + "GalRaErr                   = RA_ERR," \
-#                 + " ForcedGalaxyShape." + filter[1] + "GalDecErr                  = DEC_ERR," \
-#                 + " ForcedGalaxyShape." + filter[1] + "GalChisq                   = CHISQ "
-
-            sqlLine = sqlUtility("UPDATE ForcedGalaxyShape AS a, " + cpqTable + " AS b SET")
-            sqlLine.group("a." + filter[1] + "ippDetectID",     "b.DET_ID")
-            sqlLine.group("a." + filter[1] + "forcedSummaryID", "b.IMAGE_ID")
-            sqlLine.group("a." + filter[1] + "GalMajor",        "b.MAJOR_AXIS")
-            sqlLine.group("a." + filter[1] + "GalMajorErr",     "b.MAJOR_AXIS_ERR")
-            sqlLine.group("a." + filter[1] + "GalMinor",        "b.MINOR_AXIS")
-            sqlLine.group("a." + filter[1] + "GalMinorErr",     "b.MINOR_AXIS_ERR")
-            sqlLine.group("a." + filter[1] + "GalMag",          "b.MAG")
-            sqlLine.group("a." + filter[1] + "GalMagErr",       "b.MAG_ERR")
-# These fields don't exist.
-#            sqlLine.group("a." + filter[1] + "GalRa",           "b.RA")
-#            sqlLine.group("a." + filter[1] + "GalDec",          "b.DEC")
-#            sqlLine.group("a." + filter[1] + "GalRaErr",        "b.RA_ERR")
-#            sqlLine.group("a." + filter[1] + "GalDecErr",       "b.DEC_ERR")
-            sqlLine.group("a." + filter[1] + "GalChisq",        "b.CHISQ")
-            sql = sqlLine.makeEquals("WHERE a.objID = b.OBJ_ID AND a.galModelType = b.MODEL_TYPE AND b.Photcode = " + photcode)
-            
+            # Should GalChiSq fold in Npix somehow?  
+            sql = "UPDATE ForcedGalaxyShape JOIN " \
+                + cpqTable + " AS cpq ON (cpq.row = (ForcedGalaxyShape.row* " + str(filterCount) + ")-(" + str(filterCount) + " - " + str(filter[0]) + ")) " \
+                + " SET " + \
+                + " ForcedGalaxyShape." + filter[1] + "ippDetectID                = DET_ID," \
+                + " ForcedGalaxyShape." + filter[1] + "forcedSummaryID            = IMAGE_ID," \
+                + " ForcedGalaxyShape." + filter[1] + "GalModelType               = MODEL_TYPE," \
+                + " ForcedGalaxyShape." + filter[1] + "GalMajor                   = MAJOR_AXIS," \
+                + " ForcedGalaxyShape." + filter[1] + "GalMajorErr                = MAJOR_AXIS_ERR," \
+                + " ForcedGalaxyShape." + filter[1] + "GalMinor                   = MINOR_AXIS," \
+                + " ForcedGalaxyShape." + filter[1] + "GalMinorErr                = MINOR_AXIS_ERR," \
+                + " ForcedGalaxyShape." + filter[1] + "GalMag                     = MAG," \
+                + " ForcedGalaxyShape." + filter[1] + "GalMagErr                  = MAG_ERR," \
+                + " ForcedGalaxyShape." + filter[1] + "GalRa                      = RA," \
+                + " ForcedGalaxyShape." + filter[1] + "GalDec                     = DEC," \
+                + " ForcedGalaxyShape." + filter[1] + "GalRaErr                   = RA_ERR," \
+                + " ForcedGalaxyShape." + filter[1] + "GalDecErr                  = DEC_ERR," \
+                + " ForcedGalaxyShape." + filter[1] + "GalChisq                   = CHISQ "
 
             try: self.scratchDb.execute(sql)
@@ -236,25 +215,3 @@
 
         
-        self.logger.infoPair("Dropping row column from ", "ForcedGalaxyShape table")
-        self.scratchDb.dropColumn("ForcedGalaxyShape", "row")
-
-        self.logger.infoPair("setting minmaxobjid for ", "ForcedGalaxyShape table")
-        self.setMinMaxObjID(["ForcedGalaxyShape"])
-        self.logger.infoPair("checking if we have detections", "ForcedGalaxyShape table")
-        rowcount = self.scratchDb.getRowCount("ForcedGalaxyShape")
-        if rowcount == 0:
-            self.logger.infoPair("skipping this one", "ForcedGalaxyShape")
-            self.skipBatch = False
-            return True
-        else:
-            return True
-
-    '''
-    Populate psps tables
-    '''
-    def populatePspsTables(self):
-        
-        if not self.populateForcedGalaxyShapeTable(): return False
-
-        # My example is removing objID duplicates.  Since ForcedGalaxyShape can have multiple models for a given object, I'm not doing that.
-
+        
Index: /trunk/ippToPsps/test/fulltest.sh
===================================================================
--- /trunk/ippToPsps/test/fulltest.sh	(revision 38963)
+++ /trunk/ippToPsps/test/fulltest.sh	(revision 38964)
@@ -1,6 +1,3 @@
 #!/bin/csh -f
-
-set dbuser = czw
-set dbpass = -pczw
 
 chmod +x mkgpc1data.dvo mkgpc1.sh
@@ -193,6 +190,6 @@
   # does the database already exist?
   # XXX this command will blow away an existing database!!
-  mysql -h localhost -u $dbuser $dbpass -e "create database if not exists ipptopsps_test" || exit 3
-  mysql -h localhost -u $dbuser $dbpass ipptopsps_test < $IPPTOPSPS_DATA/ippToPspsDbSchema.sql || exit 3
+  mysql -h localhost -u dvo -pdvo -e "create database if not exists ipptopsps_test" || exit 3
+  mysql -h localhost -u dvo -pdvo ipptopsps_test < $IPPTOPSPS_DATA/ippToPspsDbSchema.sql || exit 3
   echo " ---- init ipptopsps_test: done ----"
 endif
@@ -204,6 +201,6 @@
 
   # create the database (ignore failure if it already exists)
-  mysql -h localhost -u $dbuser $dbpass -e "drop database if exists ipptopsps_test_scratch"
-  mysql -h localhost -u $dbuser $dbpass -e "create database ipptopsps_test_scratch"
+  mysql -h localhost -u dvo -pdvo -e "drop database if exists ipptopsps_test_scratch"
+  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_test_scratch"
   ippjython setupScratchDb.py -test < /dev/null
   if ($status) exit
Index: /trunk/ippToPsps/test/mkgpc1.sh
===================================================================
--- /trunk/ippToPsps/test/mkgpc1.sh	(revision 38963)
+++ /trunk/ippToPsps/test/mkgpc1.sh	(revision 38964)
@@ -59,9 +59,6 @@
   echo ntable: $ntable
   if ($ntable != 25) then
-    if ($ntable != 21) then
-	echo "expected 25 lines (24 tables), but got $ntable, not deleting"
-	exit 2
-    endif
-    echo "Found old style 21 line (20 table) version of the database, so not blocking deletion."
+    echo "expected 25 lines (24 tables), but got $ntable, not deleting"
+    exit 2
   endif
 
Index: /trunk/ippToPsps/test/mkgpc1data.dvo
===================================================================
--- /trunk/ippToPsps/test/mkgpc1data.dvo	(revision 38963)
+++ /trunk/ippToPsps/test/mkgpc1data.dvo	(revision 38964)
@@ -3,6 +3,5 @@
 input tap.dvo
 
-opihi verbose on
-if (not($?VERBOSE)) set VERBOSE = 1
+if (not($?VERBOSE)) set VERBOSE = 0
 if (not($?PARALLEL)) set PARALLEL = 0
 
@@ -71,6 +70,6 @@
   $dbhost = localhost
   $dbname = gpc1test
-  $dbuser = czw
-  $dbpass = czw
+  $dbuser = dvo
+  $dbpass = dvo
 
   $RA = 10.0
Index: /trunk/ippToPsps/test/sastest.sh
===================================================================
--- /trunk/ippToPsps/test/sastest.sh	(revision 38963)
+++ /trunk/ippToPsps/test/sastest.sh	(revision 38964)
@@ -1,6 +1,3 @@
 #!/bin/csh -f
-
-set dbuser = czw
-set dbpass = -pczw
 
 chmod +x mksasdata.dvo mkgpc1.sh
@@ -160,6 +157,6 @@
   # does the database already exist?
   # XXX this command will blow away an existing database!!
-  mysql -h localhost -u $dbuser $dbpass -e "create database ipptopsps_test"
-  mysql -h localhost -u $dbuser $dbpass ipptopsps_test < $IPPTOPSPS_DATA/ippToPspsDbSchema.sql
+  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_test"
+  mysql -h localhost -u dvo -pdvo ipptopsps_test < $IPPTOPSPS_DATA/ippToPspsDbSchema.sql
 endif
 
@@ -168,6 +165,6 @@
 
   # create the database (ignore failure if it already exists)
-  mysql -h localhost -u $dbuser $dbpass -e "drop database ipptopsps_scratch"
-  mysql -h localhost -u $dbuser $dbpass -e "create database ipptopsps_scratch"
+  mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_scratch"
+  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_scratch"
   ippjython setupScratchDb.py -test < /dev/null
   if ($status) exit
Index: /trunk/ippToPsps/test/widetest.sh
===================================================================
--- /trunk/ippToPsps/test/widetest.sh	(revision 38963)
+++ /trunk/ippToPsps/test/widetest.sh	(revision 38964)
@@ -1,6 +1,3 @@
 #!/bin/csh -f
-
-set dbuser = czw
-set dbpass = -pczw
 
 set stackqueuename = 0
@@ -51,6 +48,6 @@
   # does the database already exist?
   # XXX this command will blow away an existing database!!
-  mysql -h localhost -u $dbuser $dbpass -e "create database ipptopsps_test"
-  mysql -h localhost -u $dbuser $dbpass ipptopsps_test < $IPPTOPSPS_DATA/ippToPspsDbSchema.sql
+  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_test"
+  mysql -h localhost -u dvo -pdvo ipptopsps_test < $IPPTOPSPS_DATA/ippToPspsDbSchema.sql
 
 endif
@@ -60,6 +57,6 @@
 
   # create the database (ignore failure if it already exists)
-  mysql -h localhost -u $dbuser $dbpass -e "drop database ipptopsps_test_scratch"
-  mysql -h localhost -u $dbuser $dbpass -e "create database ipptopsps_test_scratch"
+  mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_test_scratch"
+  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_test_scratch"
   ippjython setupScratchDb.py -test
 endif

Index: /trunk/ippToPsps/test/partest.sh
===================================================================
--- /trunk/ippToPsps/test/partest.sh	(revision 38963)
+++ /trunk/ippToPsps/test/partest.sh	(revision 38964)
@@ -1,6 +1,3 @@
 #!/bin/csh -f
-
-set dbuser = czw
-set dbpass = -pczw
 
 set stackqueuename = 0
@@ -52,6 +49,6 @@
   # does the database already exist?
   # XXX this command will blow away an existing database!!
-  mysql -h localhost -u $dbuser $dbpass -e "create database ipptopsps_test"
-  mysql -h localhost -u $dbuser $dbpass ipptopsps_test < $IPPTOPSPS_DATA/ippToPspsDbSchema.sql
+  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_test"
+  mysql -h localhost -u dvo -pdvo ipptopsps_test < $IPPTOPSPS_DATA/ippToPspsDbSchema.sql
 
 endif
@@ -91,11 +88,11 @@
 
   # create the database (ignore failure if it already exists)
-  mysql -h localhost -u $dbuser $dbpass -e "drop database ipptopsps_test_scratch1"
-  # mysql -h localhost -u $dbuser $dbpass -e "drop database ipptopsps_scratch2"
-  # mysql -h localhost -u $dbuser $dbpass -e "drop database ipptopsps_scratch3"
-
-  mysql -h localhost -u $dbuser $dbpass -e "create database ipptopsps_test_scratch1"
-  # mysql -h localhost -u $dbuser $dbpass -e "create database ipptopsps_scratch2"
-  # mysql -h localhost -u $dbuser $dbpass -e "create database ipptopsps_scratch3"
+  mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_test_scratch1"
+  # mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_scratch2"
+  # mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_scratch3"
+
+  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_test_scratch1"
+  # mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_scratch2"
+  # mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_scratch3"
 
   ippjython setupScratchDb.py -test dummy ipptopsps_test_scratch1